@@ -110,11 +110,11 @@ class App:
 
         try:
             if handler is not None:
-                if inspect.isclass(handler):
-                    handler = getattr(handler(), request.method.lower(), None)
-                    if handler is None:
-                        raise AttributeError(
-                            "Method not allowed", request.method)
+                # if inspect.isclass(handler):
+                #     handler = getattr(handler(), request.method.lower(), None)
+                #     if handler is None:
+                #         raise AttributeError(
+                #             "Method not allowed", request.method)
 
                 response = handler(request, **kwargs)
             else:
@@ -155,11 +155,6 @@ class App:
     def add_middleware(self, middleware_cls):
         self.middleware.add(middleware_cls)
 
-    def change_template_env(self, templates_dir):
-        self.templates_env = Environment(
-            loader=FileSystemLoader(os.path.abspath(templates_dir)))
-        self.templates_dir = templates_dir
-
     def register_collection(self, collection):
         assert collection not in self.collections, f"Collection {collection} already registered"
         for path in collection.routes.keys():
